@@ -78,7 +78,8 @@ func TestWalkNilNode(t *testing.T) {
 		&Params{},
 		&FuncDecl{},
 		&MethodDecl{},
-		&FieldDefinition{},
+		&Field{},
+		&ClassElement{},
 		&ClassDecl{},
 		&LiteralExpr{},
 		&Element{},
@@ -96,7 +97,6 @@ func TestWalkNilNode(t *testing.T) {
 		&Args{},
 		&NewExpr{},
 		&CallExpr{},
-		&OptChainExpr{},
 		&UnaryExpr{},
 		&BinaryExpr{},
 		&CondExpr{},
